@@ -9,7 +9,8 @@ import adafruit_ssd1327
 displayio.release_displays()
 
 # Use for I2C
-i2c = board.I2C()
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 display_bus = displayio.I2CDisplay(i2c, device_address=0x3D)
 
 # Use for SPI
